# Copyright (C) 2012 Red Hat, Inc.  All rights reserved.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of version 2 of the GNU General Public License
# as published by the Free Software Foundation.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Authors: Michal Minar <miminar@redhat.com>

"""
Filters used in mako templates. For usage see:
  http://docs.makotemplates.org/en/latest/filtering.html
"""
import base64
import markupsafe

def hs(text):   #pylint: disable=C0103
    """
    Is filter similar to mako's h. It differs in not escaping text,
    that has been marked as safe (has attribute 'safe' equal to True).
    @return escaped text for not safe strings
    """
    if getattr(text, 'safe', False):
        return text
    return markupsafe.escape(text)

def b64enc(text):
    """
    @return text compressed in base64 format
    """
    return base64.urlsafe_b64encode(text)
